==> tetzle_2.1.6.orig.tar.gz: tetzle-2.1.6/translations/tetzle_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Background:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;系统语言&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>提示</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>缩 &amp;小</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>放 &amp;大</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>全&amp;屏</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;设置</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;帮助</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;控制</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;关于</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>关于 &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>控制</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>关于 Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>版权所有 &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>基于 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 协议发布</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>选择 OpenGL 版本。</translation>
    </message>
    <message>
        <source>version</source>
        <translation>版本</translation>
    </message>
</context>
</TS>

==> tetzle_3.0.1.orig.tar.gz: tetzle-3.0.1/translations/tetzle_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Background:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;系统语言&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>提示</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>缩 &amp;小</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>放 &amp;大</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>全&amp;屏</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;设置</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;帮助</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;控制</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;关于</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>关于 &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>控制</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>关于 Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>版权所有 &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>基于 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 协议发布</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
